import { MiniAppsMethodParams, MiniAppsMethodWithOptionalParams, MiniAppsMethodWithoutParams, MiniAppsMethodWithRequiredParams } from './types/methods.js';

interface PostEventOptions {
    /**
     * Origin used while posting a message.
     *
     * This option is only used if the current environment is browser (Web version of Telegram)
     * and could be used for test purposes.
     * @default 'https://web.telegram.org'
     */
    targetOrigin?: string;
}
export type PostEvent = typeof postEvent;
/**
 * Calls Mini Apps method with optional parameters.
 * @param method - method name.
 * @param params - method parameters.
 * @param options - posting options.
 * @throws {SDKError} ERR_UNKNOWN_ENV
 * @see ERR_UNKNOWN_ENV
 */
export declare function postEvent<Method extends MiniAppsMethodWithOptionalParams>(method: Method, params?: MiniAppsMethodParams<Method>, options?: PostEventOptions): void;
/**
 * Calls Mini Apps method without parameters.
 * @param method - method name.
 * @param options - posting options.
 * @throws {SDKError} ERR_UNKNOWN_ENV
 * @see ERR_UNKNOWN_ENV
 */
export declare function postEvent(method: MiniAppsMethodWithoutParams | MiniAppsMethodWithOptionalParams, options?: PostEventOptions): void;
/**
 * Calls Mini Apps method with parameters.
 * @param method - method name.
 * @param params - method parameters.
 * @param options - posting options.
 * @throws {SDKError} ERR_UNKNOWN_ENV
 * @see ERR_UNKNOWN_ENV
 */
export declare function postEvent<Method extends MiniAppsMethodWithRequiredParams>(method: Method, params: MiniAppsMethodParams<Method>, options?: PostEventOptions): void;
export {};
