import { WithSupportsAndStateUtils } from '../../classes/WithSupportsAndStateUtils.js';
import { PostEvent } from '../../bridge/methods/postEvent.js';
import { BackButtonEvents, BackButtonState } from './types.js';
import { EventEmitter } from '../../events/event-emitter/EventEmitter.js';
import { Version } from '../../version/types.js';

type Emitter = EventEmitter<BackButtonEvents>;
/**
 * @see Usage: https://docs.telegram-mini-apps.com/platform/back-button
 * @see API: https://docs.telegram-mini-apps.com/packages/tma-js-sdk/components/back-button
 */
export declare class BackButton extends WithSupportsAndStateUtils<BackButtonState, 'show' | 'hide'> {
    private readonly postEvent;
    constructor(isVisible: boolean, version: Version, postEvent: PostEvent);
    private set isVisible(value);
    /**
     * True if BackButton is currently visible.
     */
    get isVisible(): boolean;
    /**
     * Hides the BackButton.
     */
    hide(): void;
    /**
     * Adds a new event listener.
     * @param event - event to listen.
     * @param listener - listener to add.
     */
    on: Emitter['on'];
    /**
     * Removes the event listener.
     * @param event - event to listen.
     * @param listener - listener to remove.
     */
    off: Emitter['off'];
    /**
     * Shows the BackButton.
     */
    show(): void;
}
export {};
